==> af-common-resource-1.1.14.11-sources.jar: com/af/v4/system/common/resource/mapper/SqlMapper.java <==
package com.af.v4.system.common.resource.mapper;

import com.af.v4.system.common.datasource.DynamicDataSource;
import com.af.v4.system.common.liuli.config.service.LiuLiConfigService;
import com.af.v4.system.common.liuli.utils.ApplicationUtils;
import com.af.v4.system.common.resource.enums.ResourceType;
import com.alibaba.druid.DbType;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * SQL映射器
 *
 * @author Mr.river
 */
@Component
public class SqlMapper extends AbstractResourceMapper<SqlMapper.SqlResource> {

    private static final Boolean DEFAULT_MOBILE_STATE = false;

    protected SqlMapper(ModuleMapper moduleMapper, ApplicationUtils applicationUtils, LiuLiConfigService liuLiConfigService) {
        super(moduleMapper, applicationUtils, liuLiConfigService);
    }


    @Override
    public ResourceType getResType() {
        return ResourceType.SQL;
    }

    @Override
    public String getFileName() {
        return "sql.xml";
    }

    @Override
    public String getFolderName() {
        return "sqls";
    }

    @Override
    protected SqlMapper.SqlResource buildResourceImpl(String moduleName, String key, Object value, Map<String, Object> attrMap) {
        // 所属数据源
        Object dataSource = attrMap.get("dataSource");
        // 是否支持手机端
        Object mobile = attrMap.get("mobile");
        return new SqlMapper.SqlResource(
                this,
                moduleName,
                key,
                value.toString(),
                dataSource == null ? null : dataSource.toString(),
                mobile == null ? DEFAULT_MOBILE_STATE : Boolean.parseBoolean(mobile.toString())
        );
    }

    @Override
    protected String rewriteSource(String source) {
        source = "$" + source;
        //如果使用了新格式化参数写法，需要替换为解析语法树支持的写法
        if (source.contains("${")) {
            source = source.replace("${", "{");
        }
        return source;
    }

    @Override
    protected String[] getCandidateAliasList(String key) {
        DbType dbType = DynamicDataSource.getDbType();
        String alias = switch (dbType) {
            case oracle -> key + "_oracle";
            case mysql -> key + "_mysql";
            default -> null;
        };
        if (alias != null) {
            return new String[]{alias, key};
        } else {
            return new String[]{key};
        }
    }

    /**
     * Sql资源
     */
    public static class SqlResource extends CommonResource implements MobileResourceSupport, DataSourceResourceSupport {
        /**
         * 所属数据源
         */
        private final String dataSource;
        /**
         * 是否支持手机端
         */
        private final boolean mobile;

        public SqlResource(AbstractResourceMapper<?> mapper, String moduleName, String key, Object path, String dataSource, Boolean mobile) {
            super(mapper, moduleName, key, path);
            this.dataSource = dataSource;
            this.mobile = mobile;
        }

        @Override
        public String getDataSource() {
            return dataSource;
        }

        @Override
        public boolean isMobile() {
            return mobile;
        }
    }
}

==> af-common-resource-1.1.14.30-sources.jar: com/af/v4/system/common/resource/mapper/SqlMapper.java <==
package com.af.v4.system.common.resource.mapper;

import com.af.v4.system.common.datasource.DynamicDataSource;
import com.af.v4.system.common.liuli.config.service.LiuLiConfigService;
import com.af.v4.system.common.liuli.utils.ApplicationUtils;
import com.af.v4.system.common.resource.enums.ResourceType;
import com.alibaba.druid.DbType;
import org.json.JSONObject;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * SQL映射器
 *
 * @author Mr.river
 */
@Component
public class SqlMapper extends AbstractResourceMapper<SqlMapper.SqlResource> {

    private static final Boolean DEFAULT_MOBILE_STATE = false;

    protected SqlMapper(ModuleMapper moduleMapper, ApplicationUtils applicationUtils, LiuLiConfigService liuLiConfigService) {
        super(moduleMapper, applicationUtils, liuLiConfigService);
    }


    @Override
    public ResourceType getResType() {
        return ResourceType.SQL;
    }

    @Override
    public String getFileName() {
        return "sql.xml";
    }

    @Override
    public String getFolderName() {
        return "sqls";
    }

    @Override
    protected SqlMapper.SqlResource buildResourceImpl(String moduleName, String key, Object path, JSONObject liuliValue, Map<String, Object> attrMap) {
        // 所属数据源
        Object dataSource = attrMap.get("dataSource");
        // 是否支持手机端
        Object mobile = attrMap.get("mobile");
        return new SqlMapper.SqlResource(
                this,
                moduleName,
                key,
                path.toString(),
                liuliValue,
                dataSource == null ? null : dataSource.toString(),
                mobile == null ? DEFAULT_MOBILE_STATE : Boolean.parseBoolean(mobile.toString())
        );
    }

    @Override
    protected String rewriteSource(String source) {
        source = "$" + source;
        //如果使用了新格式化参数写法，需要替换为解析语法树支持的写法
        if (source.contains("${")) {
            source = source.replace("${", "{");
        }
        return source;
    }

    @Override
    protected String[] getCandidateAliasList(String key) {
        DbType dbType = DynamicDataSource.getDbType();
        String alias = switch (dbType) {
            case oracle -> key + "_oracle";
            case mysql -> key + "_mysql";
            default -> null;
        };
        if (alias != null) {
            return new String[]{alias, key};
        } else {
            return new String[]{key};
        }
    }

    /**
     * Sql资源
     */
    public static class SqlResource extends CommonResource implements MobileResourceSupport, DataSourceResourceSupport {
        /**
         * 所属数据源
         */
        private final String dataSource;
        /**
         * 是否支持手机端
         */
        private final boolean mobile;

        public SqlResource(AbstractResourceMapper<?> mapper, String moduleName, String key, Object path, JSONObject liuliValue, String dataSource, Boolean mobile) {
            super(mapper, moduleName, key, path, liuliValue);
            this.dataSource = dataSource;
            this.mobile = mobile;
        }

        @Override
        public String getDataSource() {
            return dataSource;
        }

        @Override
        public boolean isMobile() {
            return mobile;
        }
    }
}
